#!/bin/sh
set -x
glib-gettextize --copy --force
libtoolize --automake --copy --force
intltoolize --automake --copy --force
aclocal
mkdir m4
autoconf --force
autoheader --force
automake --add-missing --copy --force-missing --foreign
